import 'package:flutter/material.dart';
import 'package:hub/flutter_flow/internationalization.dart';
import 'package:hub/flutter_flow/nav/nav.dart';
import 'package:hub/shared/components/molecules/menu/index.dart';

enum DrawerMenuEntries implements MenuEntry {
  providerSchedule,
  deliverySchedule,
  fastPass,
  completeSchedule,
  orders,
  reservations,
  visitors,
  qrCode,
  pets,
  access,
  liberations,
  messages,
  aboutProperty,
  peopleOnTheProperty,
  settings,
  logout;

  @override
  String get value {
    switch (this) {
      case DrawerMenuEntries.messages:
        return 'FRE-HUB-MESSAGES';
      case DrawerMenuEntries.liberations:
        return 'FRE-HUB-LIBERATIONS';
      case DrawerMenuEntries.reservations:
        return 'FRE-HUB-RESERVATIONS';
      case DrawerMenuEntries.access:
        return 'FRE-HUB-ACCESS';
      case DrawerMenuEntries.pets:
        return 'FRE-HUB-PETS';
      case DrawerMenuEntries.orders:
        return 'FRE-HUB-ORDERS';
      case DrawerMenuEntries.completeSchedule:
        return 'FRE-HUB-COMPLETE-SCHEDULE';
      case DrawerMenuEntries.providerSchedule:
        return 'FRE-HUB-AGE-PROV-PRESTADOR';
      case DrawerMenuEntries.deliverySchedule:
        return 'FRE-HUB-AGE-PROV-DELIVERY';
      case DrawerMenuEntries.aboutProperty:
        return 'FRE-HUB-PROPERTY';
      case DrawerMenuEntries.fastPass:
        return 'FRE-HUB-FASTPASS';
      case DrawerMenuEntries.visitors:
        return 'FRE-HUB-VISITORS';
      case DrawerMenuEntries.qrCode:
        return 'FRE-HUB-QRCODE';
      case DrawerMenuEntries.peopleOnTheProperty:
        return 'FRE-HUB-PEOPLE';
      case DrawerMenuEntries.settings:
        return 'FRE-HUB-SETTINGS';
      case DrawerMenuEntries.logout:
        return 'FRE-HUB-LOGOUT';
      default:
        return '';
    }
  }

  @override
  String get name {
    switch (this) {
      case DrawerMenuEntries.messages:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Consultar Mensagens',
          enText: 'Messages History',
        );
      case DrawerMenuEntries.liberations:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Consultar Liberações',
          enText: 'Liberations History',
        );
      case DrawerMenuEntries.reservations:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Reservas',
          enText: 'Reservations',
        );
      case DrawerMenuEntries.access:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Consultar Acessos',
          enText: 'Access History',
        );
      case DrawerMenuEntries.pets:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Pets',
          enText: 'Pets',
        );
      case DrawerMenuEntries.peopleOnTheProperty:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Pessoas na Propriedade',
          enText: 'People on the Property',
        );
      case DrawerMenuEntries.orders:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Minhas Encomendas',
          enText: 'My Orders',
        );
      case DrawerMenuEntries.completeSchedule:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Agenda Completa',
          enText: 'Complete Schedule',
        );
      case DrawerMenuEntries.providerSchedule:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Agendar Prestadores',
          enText: 'Schedule Providers',
        );
      case DrawerMenuEntries.deliverySchedule:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Agendar Delivery',
          enText: 'Schedule Delivery',
        );
      case DrawerMenuEntries.fastPass:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Fast Pass',
          enText: 'Fast Pass',
        );
      case DrawerMenuEntries.qrCode:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'QRCode de Acesso',
          enText: 'Access QRCode',
        );
      case DrawerMenuEntries.visitors:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Cadastrar Visitantes',
          enText: 'Register Visitors',
        );
      case DrawerMenuEntries.aboutProperty:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Sobre a Propriedade',
          enText: 'About the Property',
        );
      case DrawerMenuEntries.settings:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Configurações',
          enText: 'Settings',
        );
      case DrawerMenuEntries.logout:
        return FFLocalizations.of(navigatorKey.currentContext!).getVariableText(
          ptText: 'Sair',
          enText: 'Logout',
        );
    }
  }

  @override
  IconData get icon {
    switch (this) {
      case DrawerMenuEntries.messages:
        return Icons.chat_outlined;
      case DrawerMenuEntries.liberations:
        return Icons.how_to_reg_outlined;
      case DrawerMenuEntries.reservations:
        return Icons.event_available;
      case DrawerMenuEntries.access:
        return Icons.transfer_within_a_station_outlined;
      case DrawerMenuEntries.pets:
        return Icons.pets;
      case DrawerMenuEntries.peopleOnTheProperty:
        return Icons.groups;
      case DrawerMenuEntries.orders:
        return Icons.inventory_2_outlined;
      case DrawerMenuEntries.completeSchedule:
        return Icons.event;
      case DrawerMenuEntries.providerSchedule:
        return Icons.engineering_outlined;
      case DrawerMenuEntries.deliverySchedule:
        return Icons.sports_motorsports_outlined;
      case DrawerMenuEntries.fastPass:
        return Icons.attach_email_outlined;
      case DrawerMenuEntries.qrCode:
        return Icons.qr_code;
      case DrawerMenuEntries.visitors:
        return Icons.person_add_alt_1_outlined;
      case DrawerMenuEntries.aboutProperty:
        return Icons.home;
      case DrawerMenuEntries.settings:
        return Icons.settings;
      case DrawerMenuEntries.logout:
        return Icons.exit_to_app;
    }
  }

  @override
  String get route {
    switch (this) {
      case DrawerMenuEntries.messages:
        return '/messageHistoryPage';
      case DrawerMenuEntries.liberations:
        return '/liberationHistory';
      case DrawerMenuEntries.reservations:
        return '/reservation';
      case DrawerMenuEntries.access:
        return '/acessHistoryPage';
      case DrawerMenuEntries.pets:
        return '/petsPage';
      case DrawerMenuEntries.peopleOnTheProperty:
        return '/peopleOnThePropertyPage';
      case DrawerMenuEntries.orders:
        return '/packageOrder';
      case DrawerMenuEntries.completeSchedule:
        return '/scheduleCompleteVisitPage';
      case DrawerMenuEntries.providerSchedule:
        return '/provisionalSchedule';
      case DrawerMenuEntries.aboutProperty:
        return '/aboutProperty';
      case DrawerMenuEntries.deliverySchedule:
        return '/deliverySchedule';
      case DrawerMenuEntries.fastPass:
        return '/fastPassPage';
      case DrawerMenuEntries.qrCode:
        return '/qrCodePage';
      case DrawerMenuEntries.visitors:
        return '/registerVisitorPage';
      case DrawerMenuEntries.settings:
        return '/preferencesSettings';
      case DrawerMenuEntries.logout:
        return '/WelcomePage';
      default:
        return '';
    }
  }

}
