import 'package:hub/flutter_flow/nav/nav.dart';
import 'package:flutter/material.dart';
import 'package:flutter_bloc/flutter_bloc.dart';

import 'package:hub/flutter_flow/flutter_flow_theme.dart';
import 'package:hub/shared/components/molecules/modules/index.dart';
import 'package:hub/shared/components/molecules/menu/index.dart';
import 'package:hub/shared/utils/loading_util.dart';

class MenuViewFactory extends StatelessWidget {
  final MenuView view;
  final EnumMenuItem item;
  final bool expandable;
  final MenuEntries entry;

  const MenuViewFactory({
    super.key,
    required this.view,
    required this.item,
    required this.expandable,
    required this.entry,
  });

  @override
  Widget build(BuildContext context) {
    return StreamBuilder<LicenseStatus>(
      stream: LicenseRepositoryImpl.stream,
      builder: (context, snapshot) {
        if (snapshot.connectionState == ConnectionState.waiting) {
          return const Center(child: CircularProgressIndicator());
        } else if (snapshot.hasError) {
          return Center(child: Text('Error: ${snapshot.error}'));
        } else if (!snapshot.hasData || snapshot.data! == false) {
          return LoadingUtil.buildLoadingIndicator(context);
        }
        return _buildMenuBloc(context);
      },
    );
  }

  Widget buildMenu(BuildContext context) {
    return _buildMenuBloc(context);
  }



  Widget _buildMenuBloc(BuildContext context) {
    return BlocProvider(
      create: (context) => MenuViewBloc(
        style: view,
        item: item,
        menuOptions: entry.getValues,
        expandable: expandable,
      )..add(MenuViewEvent()),
      child: BlocBuilder<MenuViewBloc, MenuViewState>(
        builder: (context, state) {
          if (view == MenuView.list_grid) {
            return MenuStaggeredView(
              options: state.menuEntries,
              expandable: expandable,
              item: item,
              changeMenuStyle: () async {},
              isGrid: state.isGrid,
            );
          } else if (view == MenuView.list) {
            return MenuListView(
              options: state.menuEntries,
              expandable: expandable,
              item: item,
              changeMenuStyle: () async {},
            );
          }
          return const SizedBox();
        },
      ),
    );
  }
}
